package com.goldenwater.slaj.eme.mapper;

import java.util.List;
import org.apache.ibatis.annotations.Mapper;
import com.goldenwater.slaj.eme.domain.BusiReviewInfo;

/**
 * 应急预案评审信息 数据层
 */
@Mapper
public interface BusiReviewInfoMapper {

    /**
     * 查询应急预案评审信息
     * @param guid 查询条件
     * @return 应急预案评审信息
     */
    BusiReviewInfo selectBusiReviewInfoByGuid(String guid);

    /**
     * 查询应急预案评审信息列表
     * @param busiReviewInfo 查询条件
     * @return 应急预案评审信息集合
     */
    List<BusiReviewInfo> selectBusiReviewInfoList(BusiReviewInfo busiReviewInfo);

    /**
     * 新增应急预案评审信息
     * @param busiReviewInfo 应急预案评审信息
     * @return 影响行数
     */
    int insertBusiReviewInfo(BusiReviewInfo busiReviewInfo);

    /**
     * 修改应急预案评审信息
     * @param busiReviewInfo 应急预案评审信息
     * @return 影响行数
     */
    int updateBusiReviewInfo(BusiReviewInfo busiReviewInfo);

    /**
     * 删除应急预案评审信息
     * @param guid 主键
     * @return 影响行数
     */
    int deleteBusiReviewInfoByGuid(String guid);

    /**
     * 批量删除应急预案评审信息
     * @param guids 主键数组
     * @return 影响行数
     */
    int deleteBusiReviewInfoByGuids(String[] guids);
}
